Description: John és Jennifer Grogan friss házasok. Mindketten újságíróként dolgoznak, szeretik a munkájukat, de még jobban egymást. Amikor beköltöznek első közös otthonukba, John úgy érzi, ideje lenne igazi családot alapítani. Mivel azonban még nem érzi magát felkészültnek az apaságra, egyik barátja tanácsára örökbe fogadnak egy kölyökkutyát, hogy némi tapasztalatot szerezzenek a gondoskodásról. Marley, a pajkos és játékos labradorkölyök azonban teljesen felforgatja addigi életüket, és hamarosan katasztrófa sújtotta övezetté változtatja otthonukat...

Összes

- Összes
- Személy
- Film
- Színdarab
- Tv műsor
- Esemény
- Csoport
- Helyszín
- TV csatorna
- Cikk

- Filmek estére
- Mozi
  - Moziműsor
  - Mozi premierek
- Színház
  - Színházműsor
  - Színházi bemutatók
- Hétvége
  - Hétvége
  - Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film
- Összes
  - Filmek estére
  - Moziműsor
  - Mozi premierek
  - Színházműsor
  - Színházi bemutatók
  - Hétvége
  - Gyerek hétvége
  - Kritikák
  - Trailerek
  - Top 100 film

- Filmek estére
- Moziműsor
- Mozi premierek
- Színházműsor
- Színházi bemutatók
- Hétvége
- Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film

Programkereső

- Ma
  - Ma
  - Holnap
  - A héten
  - Hétvégén
  - Bármikor
- Budapest
  - Országos
  - Ajka
  - Békéscsaba
  - Bölcske
  - Budaörs
  - Budapest
  - Bük (Bükfürdő)
  - Cegléd
  - Debrecen
  - Dunaújváros
  - Eger
  - Gödöllő
  - Gyenesdiás
  - Gyöngyös
  - Győr
  - Gyula
  - Hévíz
  - Hódmezővásárhely
  - Kaposvár
  - Kecskemét
  - Keszthely
  - Kisújszállás
  - Kisvárda
  - Martfű
  - Miskolc
  - Nagykanizsa
  - Nagykőrös
  - Nyíregyháza
  - Pécs
  - Salgótarján
  - Siófok
  - Sopron
  - Szeged
  - Székesfehérvár
  - Szekszárd
  - Szentendre
  - Szentes
  - Szigetszentmiklós
  - Szolnok
  - Szombathely
  - Tatabánya
  - Vác
  - Veszprém
  - Zalaegerszeg
- Mozi
  - TV
  - Mozi
  - Színház
  - Koncert
  - Fesztivál
  - Kiállítás
  - Könyv
  - Egyéb

# Marley meg én

Bakancslistához adom
Marley & Me
amerikai vígjáték, filmdráma, családi film, 118 perc, 2008

## Értékelés:

761 szavazatból
Szerinted?

394 hozzászólás

John és Jennifer Grogan friss házasok. Mindketten újságíróként dolgoznak, szeretik a munkájukat, de még jobban egymást. Amikor beköltöznek első közös otthonukba, John úgy érzi, ideje lenne igazi családot alapítani. Mivel azonban még nem érzi magát felkészültnek az apaságra, egyik barátja tanácsára örökbe fogadnak egy kölyökkutyát, hogy némi tapasztalatot szerezzenek a gondoskodásról. Marley, a pajkos és játékos labradorkölyök azonban teljesen felforgatja addigi életüket, és hamarosan katasztrófa sújtotta övezetté változtatja otthonukat...
Bemutató dátuma: 2009. március 12. Forgalmazó: InterCom

## Stáblista:

### Szereplők

Owen Wilson
John Grogan
Jennifer Aniston
Jennifer Grogan
Eric Dane
Sebastian
Kathleen Turner
Ms. Kornblut
Alan Arkin
Arnie Klein

### Alkotók

- rendező: David Frankel
- forgatókönyvíró: Scott Frank Don Roos
- zeneszerző: Theodore Shapiro
- operatőr: Florian Ballhaus
- producer: Gil Netter Karen Rosenfelt
- vágó: Mark Livolsi

Stáblista mutatása

## Linkek:

- http://marleyandmemovie.com

## Kapcsolódó cikkek:

### 10 dolog, amit nem tudtál a Marley meg énről

A tündéri labrador és a Grogan házaspár története a tévében, a forgatásról szóló tíz érdekesség...

2021. december 11. PORT.hu

### Csatatérről, menhelyről Hollywoodba – 10 állatszínész története

Tíz hollywoodi állatszínész története: kutyák, egy macska és egy holló.

2020. augusztus 9. PORT.hu

### Miért nem nézem meg az Egy kutya négy útját?

És úgy általában, miért nem fogok soha többet beülni kutyás családi filmre, amikben egy zseniális...

2019. június 6. Vízer Balázs

### Jennifer Aniston itt lesz velünk!

Bár a Jóbarátok stábjának egyetlen később is valóban sikeres tagja elsősorban romantikus vígjátékairól ismert, tud...

2017. szeptember 8. Vízer Balázs

### Klisé és szirup

2009. március 13. Molnár Kata Orsolya

### Marley meg én

2009. március 12. Iványi Zsófia

### És boldogan éltek... - Marley és én

2009. március 12. Zöldi Gergely

### Kutya, gyerek, család

Az ördög Pradát visel rendezője, David Frankel látszólag sablonos eszközökkel (kutya, gyerek...) mesél látszólag elcsépelt...

2009. március 11. TóCsa

### Eben gubát

2009. március 11. Fáy Miklós
További cikkek mutatása

- Megosztom Facebookon

Szerkeszd te is a Port.hu-t!

#### Ha hiányosságot találsz, vagy valamihez van valamilyen érdekes hozzászólásod, írd meg nekünk!

Küldés

Figyelem: A beküldött észrevételeket a szerkesztőink értékelik, csak azok a javasolt változtatások valósulhatnak meg, amik jóváhagyást kapnak. Kérjük, forrásmegjelöléssel támaszd alá a leírtakat!

## Játszási időpontok

február 11. - szombat

- 10:05 DUNA Televízió

február 20. - hétfő

- 06:00 HBO

DUNA Televízió
február 11. - szombat

- 10:05

HBO
február 20. - hétfő

- 06:00

## Hozzászólások

Spoiler
Offtopik
Szerinted?

6/10
itsme1 2022 dec. 12. - 11:51:32 6/10
Ha eddig szerettem volna kutyát, ezután a film után már biztos nem kéne.
Csupán ennyi tanulságot vontam le belőle. Talán a családalapítás előtt állóknak még mondhat újat ez a film, de a fordulatos történeteket kedvelők, akik szeretik a valódi drámát és kiélezett konfliktusokat, csalódni fognak benne.
Válasz
ferinyul 2022 febr. 12. - 09:49:32 Előzmény m3246
10/10...;)
Válasz
9/10
Marton12 2021 dec. 18. - 13:39:17 9/10
Ritkán sírok filmen, de ennél megtörtént. Nem kaptam levegőt a sírástól a végénél, komolyan mondom, ilyen még soha nem fordult elő velem és ez azt jelenti, hogy ez egy igazi, szép, drámai, kellemes film amin lehet sírni is és ez bizonyos helyzetekben még jó is lehet. Nekem tetszett végül is, nem tudnám bármikor megnézni, de ha éppen úgy adódna, hogy rossz hangulatba lennék, akkor megtudnám.
Válasz
3/10
artad 2021 szept. 13. - 11:56:02 3/10
Szpojler (szerintem).
Számomra csalódás. Az, hogy ez a család jó dolgában állandóan szenved valami olyasmin, amit 2 mondattal, összefogva, józan ésszel meg lehetne oldani, de ők inkább szenvednek a floridai házuk medencéjében. A férj éppen fizetésemelést kap, az asszonynak nincs más dolga, "csak" a gyereknevelés lenne, de állandóan feszült. De majd Filliben jól fogják érezni magukat a f*s télben...
A kutya cuki, meg aktív, eleve azt nem értem, hogy egy ilyen kutya, amelyiknek ránézésre is tér kell, miért van egyáltalán bent a házban???
Borzasztóan bugyuta az egész...
Válasz
naraku535 2020 nov. 03. - 14:18:11
Szomorú ám a vége, meg állítólag vannak kivágott jelenetek pl. megeszi a jeles nyakláncot, mármint Marley.
Válasz
_goldie_ 2016 márc. 06. - 20:22:36
ez egy mosolygós családi film nagy hiba lenne Hachiko-hoz hasonlítani..
olyan jó kis zenékkel nyit a film mint az REM vagy Bob Marley
https://www.youtube.com/watch?v=i5oV342XLV8
https://www.youtube.com/watch?v=vdB-8eLEW8g
***spoiler***spoiler***
John: "sorozatosan csodák történnek velem..10 évvel ezelõtt még a joint és a joytick volt az életem..arról még aztán álmodni se mertem h Jennie éppen engem választ"
Jennifer: "a tervem:1 lépés: fogok egy hihetetlenül okos jóképû szexis pasit 2 lépés: helyette hozzád megyek" :)
Válasz
.::::::. 2014 dec. 27. - 23:54:34
Aranyos film, végig lekötött. Bár én nem hatódtam meg a végén, inkább hiányérzetem támadt a befejezéssel. Nem derült ki hogy utána mi történt a családdal. 10/7
Válasz
8/10
m3246 2014 jan. 26. - 12:35:28 8/10
Aki szereti a kutyákat annak ez a film nem nagyon tud lemenni 8 pont alá :) Aki a filmeket is szereti annak ez a film nehezen tudna felmenni 8 pont fölé... Talán egy meséhez tudnám hasonlítani amit nem gyerekeknek írtak, egészen bosszantó klissékkel... Mondhatnám hogy innentõl szpoiler de hát itt nincs történet, egyszerûen csak az életrõl van benne szó, valós történet igazából nincs a filmben... Ha megnézed az emberek 99,99% soha nem fog ilyen tökéletes életet élni, pláne nem kishazánkban! Minden a tökéletes helyen és idõben történik, minden happy end persze fõhõsünk soha nem elégedett a munkájával, amit ugyan szeret és három gyerekkel simán tudja fizetni egy tengerparti medencés házat, naná hogy felesége három gyerek után negyvenhez közeledve is simán veri bármelyik húszévest... a történet annyira tökéletes, hogy bármi nemû elégedetlenség simán vérig sértése az átlagnézõnek... de hát ez van, csak nézzük a mesét és ha valakit közben basztat egy érzés belül, hogy valami nem stimmel akkor azok a fenti sorok lesznek :) A film jó, a kutya haláli és imádni való de én nem rajongok a tökéletes happy-end-es filmekért, mert nem a valóságot mutatják be, a valóság sajnos nem ilyen... 8/10
Válasz
cszilvi84 2013 dec. 30. - 19:18:18
Na, eljött a karácsony, és újból megnéztem évekkel a bemutató után. Annó moziban néztük meg, és igazából akkor is lekötött, de elgondolkodtatott, hogy másoknak mi minden lehet a kifogásuk ellene.
Ez egy hangulatfilm, és ha alapvetõen nem vagy rá vevõ, akkor nem fog elkapni se most, se máskor. Igen, vannak ilyen filmek, és nem vagyok biztos benne, hogy azért, mert nincs benne drámai konfliktus, akció, csavar és meglepõdés, akkor már azonnal unalmas.
Olvastam már Peter Meyle könyvet, az az angol pasi, aki Provance-ba költözött, és egyszerûen kis történetekbõl összefûzött regényeket ír arról, hogy milyen ott élni. Egy idõben zabálták az összes könyvét, pedig nincs benne semmi nagy sztori, semmi rejtély, semmi dráma. Csak apró, aranyos történetek és érzések, és mégis jó. Igaz, nem fogom tudni felidézni a részleteket, mert nincs benne megfogható konfliktus, aztán kiteljesedés és megoldás, mert ez nem az a mûfaj. Ez akkor jó, amikor éppen olvasod, és megy át rajtad. Na, szerintem ez a film is épp ilyen. Csak hagyni kell, hogy átmenjen rajtunk, és csak rá kell feküdni, hadd vigyen.
Amikor elõször láttam, nem tudtam, mirõl fog szólni, úgyhogy nem volt semmi elvárásom.
SPOILER
Egyszerû volt, és engem éppen ezért kötött le, észre sem vettem, hogy milyen hosszú. Már más filmhez is írtam, hogy nem csak a bonyolult, odafigyelést és logikát is igénylõ sztorikat szeretem, hanem a szándékosan egyenes vonalúakat is. Tetszett a mozaikos begyorsítás, amire mások azt írták, hogy "miaszarvoltez?", mert ötletesen gyûjtötte egybe a fõbb momentumokat. Tetszett a "barát", aki egyben volt versenytárs, jóbarát és rossz szellem is, és igazából végig azon gondolkoztam, hogy mi a csudától ilyen nagy barátok ezek, amikor konkrétan semmi közös vonás nnincs bennük, se az állatokat, se a családi elképzelést tekintve. Általa láthattuk meg igazán a családfõ belsõ konfliktusait: karrier vagy család... Mert igen, ezen nem csak a nõk filózhatnak, vagy nem csak nekik van szükségük arra, hogy ha szakmailag lehagyják õket, akkor azt valamilyen formában feldolgozzák.
Megmutatkozott az is, hogy Marley több szinten is részt vett a család életének alakulásában. Akárhogy is nézzük, a hapsi múzsája lett, és megtanulta általa, hogy szakmailag azt az utat kell követnie, amihez valóban tehetsége van. Valaki írta, hogy mennyire nem életszerû az, hogy heti két cikkbõl háromgyerekes családot tart el... Nem tudom, mennyire voltak túlzások az életkörülmények, de ha az USA-ban valakinek egy magas presztízsû lapnál saját rovata van, az nem kevés pénzt visz ám haza! És azt is írtam már, hogy nem szokás házat venni, inkább a bérlés a gyakoribb, ami azért rögtön más...
De nem kanyarodok el a kutyától! Marley volt az elsõ feladat egy olyan pár életében, akik relatíve késõn, 30 éves koruk után vállaltak gyereket. Marley volt a támasz az elsõ elvesztésében, és a tanúja annak, ahogyan a gazdája szépen lassan valóban felnõtté és apává érik. És végre igazi gazdává. Nem éreztem, hogy olyan önzõ lett volna, és csak a kutyával foglalkozott volna, azt egyetlen család sem ússza meg, hogy apuka egy nagy adaggal kevesebbet tudjon a gyerekek ellátásáról, az otthoni dolgokról, mint anyuka. Anyuka 24 órában van helyben, nem lehet elérni azt a szintet, amilyenben õ van, egyszerûen nem lehet. És nem ez az elsõ, de nem is az utolsó család, ahol túlvállalják magukat, és összecsapnak a fejek fölött a hullámok, és kiabálni kell, aztán lecsendesedni és újratervezni, és apát még jobban bevonni. Ez ilyen, és mindenki útközben tanulja meg.
SPOILER VÉGE
Sok pici hangulat, errõl szól az életünk.
Nekem négy év elteltével is ugyanúgy bejön :)Van benne minden. Szerelem, munka, fájdalom, elválás, csalódás, és minden csak olyan erõvel, mint ahogy az életben, nem pedig filmszerûen többszörösére erõsítve. Van, amikor az kell, hogy egy konfliktus köré szervezõdjön egy történet, és akkor minden ki van hegyezve, de nekem nem volt nehéz elfogadni, hogy ez csak egyszerûen egy másik mûfaj.
Válasz
Milibindi 2013 dec. 27. - 02:40:28
Inkább az az állatkínzás, amire a törvény kényszerít, hogy pórázon ráncigáld a kutyát! Egy családtagként tartott, szocializált kutya senkit nem fog megharapni. Mikor pici volt Mili alig várták a napközis, parkban játszó gyerekek, hogy sétálni induljunk, miután haza értem a gimibõl. Együtt szaladgáltak játszottak , hol a kutya futott a gyerek után hol õk kergették a kutyát. Szerencsére normális tanító nénijük volt, õ is megsimogatta Milit meg minden. Kutyának is gyerekeknek is nagy öröm volt. Ez többet ér a pórázon való sétálnál! (vagy ha másik kutyával játszik az is)
Válasz
9/10
Tomi9046 2013 dec. 27. - 02:31:49 9/10
Nahát ez egy fantasztikus film volt... 23 éves fiú létemre még én is megkönnyeztem. És soha nem volt még kutyám. Ezt drámának mondanám vígjáték elemekkel. Olyan érzése van az embernek, mint amikor a Forrest Gump-ot nézte. Ott is sok jelenetnél nevetett az ember, aztán jöttek a drámai pillanatok. Én ezeket a filmeket imádom. :)
Válasz
Milibindi 2013 dec. 27. - 02:29:38 Előzmény kovacsjolika
Dehogynem! A kutya inkább az ember tartja fajtársának , mint a másik kutyát, és gazdája között egyfajta anya-gyerek kapcsolat alakul ki. Ezt már bebizonyították az etológusok. labrador meg kifejezetten család centrikus kutya, lelkibeteg is lenne ha kicsapnád a kertbe mondván nagy a mozgás igénye. Nekem dalmatái vannak. Amúgy meg hatalmas tévedés, hogy kert kell a kutyának , kinti kutyákat ugyanúgy napi 3 szor sétálni kell vinni ,mint a panelosokat! Õk sem a kertben szeretek lenni , hanem velünk. Spektrumon láttam róluk filmet és ott mondták , pl azt hogy ez a fajta ugymond lenézi azt aki nem hozzá méltóan tartja.Természetesen az is elhangzott, hogy nem kertbe való. Mennyire igaz! Két féle dalmatás gazdi van, az egyik mint én egy életre beleszeret amiért ilyen okos ragaszkodó(én is) másik meg közli hogy õ még ilyen buta kutyát látott (pl unokatesóm , egy ismerõsünk ) , na õk kertben tartják nem bent családtagként.
Válasz
Milibindi 2013 dec. 27. - 02:15:16 Előzmény bloodwyn
Én is sírtam egy csomót utána. Én sem értem miért vígjáték , én is valami vidám filmre számítottam. Ha tudom , hogy ez a vége meg sem nézem. Mili 13 és fél éves úgyhogy pláne nem szeretek ilyeneket látni:S Amúgy meg a "doktornõ" marhaságokat beszélt. A gyomorcsavarodás nem attól van, hogy gyorsan eszik vagy iszik a kutya, hanem attól,ha szaladgál evés után. Sajnos sok gazdi nem tudja, hogy kaja után a kutyának 1-2 óra pihi kell és utána szabad játszania futni. Több kutyát tudok sajnos, akinek ez lett a veszte hogy nem tudták a gazdái és labdáztak vele etetés után. Másik meg , hogy ilyenkor asszem 4 órán (???) belül meg kell mûteni a kutyát különben nem lehet megmenteni. Ha túlélte többé már nem lesz gond ,mert odavarrják a gyomrot .
Válasz
sfran12 2013 dec. 26. - 23:27:12
Most néztem meg a filmet és teljesen fel vagyok háborodva a mûfaji besorolásán: 'amerikai vígjáték'. Úgy ültem le tévézni, hogy majd egy kis vicces, vidám filmet látok, erre az utolsó 25 perc szomorú, sírdogálós hangulatú. Miért nem nevezik a mûfaját 'családi filmdráma'-nak??? Ha ezt tudom, nem ma néztem volna meg, hanem amikor szomorkodni támad kedvem. Borzasztó baklövés.
Válasz
2/10
bloodwyn 2013 okt. 19. - 10:06:31 2/10
Én is végigsírtam a végét (nyugi lány vagyok). A kutya nagyon szerethetõ benne, kedves kis film. 10/8
Válasz
9/10
Obsession 2013 márc. 31. - 18:56:35 9/10
Nem vagyok az az érzelmes, filmek végén sírós típus, de ennek a filmnek a végén végig könnyben volt a szemem és alig bírtam visszatartani, hogy ne sírjak :) Lehet, hogy csak egy kutya, de mégis nagyon megható volt :)
Válasz
Moxoaa 2013 márc. 30. - 17:49:04
A könyv sokkal szórakoztatóbb!
Válasz
nikoletta793 2013 márc. 16. - 22:21:28 Előzmény TeliholdX
jaj ez a film annyira szeretheto! valahogy azt hittem ez a szokasos kutya-gazdi sztori lesz de ez valahogy tobb ennel. nagyon nagyon aranyos film a csalad kedvence lehet. gyerekekkel egyutt nezni felejthetetlen elmeny szerintem. :)
Válasz
7/10
TeliholdX 2012 dec. 16. - 19:00:58 7/10
ez nem tudom hol vígjáték... inkább olyan családi dráma szerûség...
kb a film feléig teljesen unalmasnak tûnt... de a 2. felétõl átmegy, amikor beteg lesz a kutya, akkor érti meg az ember a film mondanivalóját. és igen, elég pityergõs film, összességében nem rossz... 7/10
Válasz
Sadenal 2012 okt. 19. - 19:16:49
Ez is jó pityergõs film volt, bár azért sajnálom, hogy Owen Wilson még mindig nem elég jó színész. Sírnia tudnia kéne, pláne ilyen filmeknél. Amúgy a Hacsi tényleg sokkal szomorúbb és jobban megríkatott. Azért ez is megható volt.
8/10
Válasz
Összes hozzászólás

## Értékelés:

761 szavazatból
Szerinted?

394 hozzászólás

Vetítések:
10:05, szombat (február 11.)
DUNA Televízió

# Mozi lista

- Budapest Kertmozi - Városmajor - Virág Benedek Ház
- Buda Bed Cinema - Ágymozi
- Autósmozi - Fővárosi Autópiac Budapest
- Westend Drive-In Cinema Autósmozi
- Cinema City Allee
- Cinema City Aréna
- Müpa Autósmozi
- Újpesti autósmozi
- Cinema City Campona
- Kino Cafe mozi

Kedvenc mozik szerkesztése »

# PORT.hu a Facebookon

##### Figyelmeztetés

Az értesítések jelenleg le vannak tiltva! Amennyiben szeretnél cikkajánlókat kapni, kérlek, hogy a böngésző Beállítások / Értesítések menüpontja alatt állítsd be az értesítések engedélyezését!

## Bejelentkezés

Jelentkezz be!

Belépek Facebookkal
VAGY
Hibás email cím vagy jelszó!
Elfelejtettem a jelszavam
Maradjak belépve
Regisztrálok»